<?php

namespace App\Controller\Admin;

use App\Entity\ParametrePartenaires;
use Throwable;
use App\Entity\Partenaires;
use App\Entity\ParametreSite;
use App\Form\PartenairesType;
use App\Service\ImageService;
use App\Repository\LanguageRepository;
use App\Repository\PartenairesRepository;
use Symfony\Component\HttpClient\HttpClient;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Security;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;

/**
 * @Security("not is_granted('ROLE_BLOG')")
 * @Route("/console")
 */
class PartenairesController extends AbstractController
{

    private $imageService;

    public function __construct(ImageService $imageService)
    {
       $this->imageService = $imageService;
    }

    /**
     * @Route("/partenaires", name="admin_partenaires_list")
     */
    public function admin_index(Request $request,PartenairesRepository $partenaires)
    {
        $service_partenaire = null;
        $invitation_accepted = [];
        $invitation_attente = [];
        $invitation_en_attente_accepted = [];
        $invitation_reciver = [];
        $all_invitation_reciver = [];
        $domaine_hrz = [];
        $partenaires = $partenaires->findAll();
        $parametreSite = $this->getDoctrine()->getRepository(ParametreSite::class)->findOneBy([],['id'=> 'DESC']);
        $parametre_partenaire = $this->getDoctrine()->getRepository(ParametrePartenaires::class)->findOneBy(['actif'=> true]);
        $baseurl = $request->getScheme() . '://' . $request->getHttpHost() . $request->getBasePath();
        if ($parametreSite && $parametreSite->getDomainApiHrz() != null && $parametreSite->getTokenApiHrz() != null) {
            $client = HttpClient::create();
            try {
                $response_api = $client->request('GET',
                    $parametreSite->getDomainApiHrz().'/api/custom/service-hrz',
                    [ 'headers' => ['Accept' => 'application/json'],
                      'query' => [
                         'domain' => $baseurl,
                         'token' => $parametreSite->getTokenApiHrz(),
                       ],
                    ]
                );

                if ($response_api->getStatusCode() === 200) {
                    $liste_service = $response_api->toArray();
                    if($liste_service){
                        $domaine_hrz = $liste_service['domaine'];

                        if ($liste_service['demande_accepted']) {
                            $invitation_accepted = array_map(function($e) {
                                return $e['domaine_reciver'];
                            }, $liste_service['demande_accepted']);
                        }

                        if ($liste_service['demande_en_attente']) {
                            $invitation_attente = array_map(function($e) {
                                return $e['domaine_reciver'];
                            }, $liste_service['demande_en_attente']);
                        }

                        if ($liste_service['demande_en_attente_accepted']) {
                            $invitation_en_attente_accepted = array_map(function($e) {
                                return $e['domaine_sender'];
                            }, $liste_service['demande_en_attente_accepted']);
                        }

                        if ($liste_service['demande_reciver']) {
                            $invitation_reciver = array_map(function($e) {
                                return $e['domaine_sender'];
                            }, $liste_service['demande_reciver']);
                        }

                        $all_invitation_reciver = $liste_service['demande_reciver'];
                    
                        foreach ($liste_service['service'] as $value) {
                            if(isset($value['alias']) && $value['alias'] == 'offre-partenaire'){
                                $service_partenaire = $value;
                            }
                        }
                    }
                }
            } catch (Throwable $th) {
                //throw $th;
            }
        }

 
        return $this->render('admin/dashboards/partenaires/_list.html.twig', [
             'partenaires' => $partenaires,
             'service_partenaire'=> $service_partenaire,
             'domaine_hrz'=> $domaine_hrz,
             'invitation_attente'=> $invitation_attente,
             'invitation_accepted'=> $invitation_accepted,
             'invitation_en_attente_accepted'=> $invitation_en_attente_accepted,
             'invitation_reciver'=> $invitation_reciver,
             'all_invitation_reciver'=> $all_invitation_reciver,
             'parametre_partenaire' => $parametre_partenaire
        ]);
    }

    /**
     * @Route("/partenaire/add", name="admin_partenaire_add")
     */
    public function addPartenaire(Request $request,LanguageRepository $language)
    {
        $languages = $language->findActifLang();
        $_locale = $request->getLocale();

        $partenaire = new Partenaires();
        $form = $this->createForm(PartenairesType::class, null);
 
         $form->handleRequest($request);
         if ($form->isSubmitted() && $form->isValid()) {

            $entityManager = $this->getDoctrine()->getManager();
            $data = $form->getData();
            $request_data = $request->request->all();
            $partenaire->setCreatedAt(new \DateTimeImmutable());
        
            $partenaire->setActif($data->isActif() == '1'?true:false);
            $partenaire->setActifTitre($data->isActifTitre() == '1'?true:false);
            $partenaire->setUrl($data->getUrl());

            if($languages){
                foreach($languages as $language)
                {
                    $partenaire->translate($language->getLanguageCode())->setTitre($data->getTitre1());
                    $partenaire->translate($language->getLanguageCode())->setText($data->getText1());

                    if ($language->getLanguageCode() == $_locale) {
                        $partenaire->translate($language->getLanguageCode())->setSlug($request_data['partenaires']['slug']);
                    }else{
                        $partenaire->translate($language->getLanguageCode())->setSlug($request_data['partenaires']['slug'].'-'.$language->getLanguageCode());
                    }
        
                    $partenaire->translate($language->getLanguageCode())->setMetaTitle($request_data['partenaires']['meta_title']);
                    $partenaire->translate($language->getLanguageCode())->setMetaDescription($request_data['partenaires']['meta_description']);
                    $partenaire->translate($language->getLanguageCode())->setSchema($request_data['partenaires']['schema']);
                    $partenaire->translate($language->getLanguageCode())->setBreadcrumb($request_data['partenaires']['breadcrumb']);
                }
            }

            $image = $request->request->get('image');
            if($image){
                $partenaire->setImage($image);
                $this->imageService->thumbnail($image);
            }

            $entityManager->persist($partenaire);
            $partenaire->mergeNewTranslations();
            $entityManager->flush();

            $this->addFlash('success', 'Vos données ont été enregistrées avec succès.');  
            return $this->redirectToRoute('admin_partenaires_list');
         }
 
         return $this->render('admin/dashboards/partenaires/_create.html.twig',array(
             'form' => $form->createView(),
        ));
    }


    /**
     * @Route("/partenaire/edit/{id}", name="admin_partenaire_edit")
     */
    public function editPartenaire(Request $request, Partenaires $partenaire)
    {
        $_locale = $request->getLocale(); 
           
        $partenaire = $this->getDoctrine()->getRepository(Partenaires::class)->find($partenaire->getId());

        if(!$partenaire){
            return $this->redirectToRoute('admin_partenaires_list');
        }
 
        $partenaire->setTitre1((string)$partenaire->translate($_locale)->getTitre());
        $partenaire->setText1((string)$partenaire->translate($_locale)->getText());

        $a_partenaire = array();
        $a_partenaire['id'] = $partenaire->getId();
        $a_partenaire['image'] = $partenaire->getImage();

        $form = $this->createForm(PartenairesType::class,$partenaire,[
             'slug'=> $partenaire->translate($_locale)->getSlug(),
             'meta_title'=> $partenaire->translate($_locale)->getMetaTitle(),
             'meta_description'=> $partenaire->translate($_locale)->getMetaDescription(),
             'schema'=> $partenaire->translate($_locale)->getSchema(),
             'breadcrumb'=> $partenaire->translate($_locale)->getBreadcrumb(),
        ]);

        $form->handleRequest($request);

        //traitement après le sauvegarde
        if ($form->isSubmitted() && $form->isValid()) {

            $em = $this->getDoctrine()->getManager(); 
            $data = $form->getData();
            $request_data = $request->request->all();

            $partenaire->setUpdatedAt(new \DateTimeImmutable()); 
            $partenaire->setActif($data->isActif() == '1'?true:false);
            $partenaire->setActifTitre($data->isActifTitre() == '1'?true:false);
            $partenaire->setUrl($data->getUrl());
            $partenaire->translate($_locale)->setTitre($data->getTitre1());
            $partenaire->translate($_locale)->setText($data->getText1());

            $partenaire->translate($_locale)->setSlug($request_data['partenaires']['slug']);
            $partenaire->translate($_locale)->setMetaTitle($request_data['partenaires']['meta_title']);
            $partenaire->translate($_locale)->setMetaDescription($request_data['partenaires']['meta_description']);
            $partenaire->translate($_locale)->setSchema($request_data['partenaires']['schema']);
            $partenaire->translate($_locale)->setBreadcrumb($request_data['partenaires']['breadcrumb']);

            $delete_image = $request->request->get('delete_image');
            if($delete_image){
                $partenaire->setImage(null);
            }
             
            $image = $request->request->get('image');
           
            if($image){
                $partenaire->setImage($image);
                $this->imageService->thumbnail($image);
            }

            $em->flush();

            $this->addFlash('success', 'Vos données ont été modifié avec succès.');
            return $this->redirectToRoute('admin_partenaires_list');
        }
               
        return $this->render('admin/dashboards/partenaires/_edit.html.twig', array(
            'partenaire' => $partenaire,
            'a_partenaire' => $a_partenaire,
            'form' => $form->createView(),
        ));
    }
    

    /**
    * @Route("/partenaire/remove", name="admin_remove_partenaire")
    */
    public function removePartenaire(Request $request) 
    {
        if($request->isMethod('Post')){
            $deleted_ids = $request->request->get('deleted_ids');
            $em = $this->getDoctrine()->getManager();
            if($deleted_ids){
                foreach(explode(",", $deleted_ids) as $id){
                    $partenaire = $this->getDoctrine()->getRepository(Partenaires::class)->find($id);
                    if($partenaire){
                        $em->remove($partenaire);
                        $em->flush();	
                    }
                }  
                
                return new JsonResponse(['message'=> 'Vos données a été supprimée avec succès.']);
            }
        }         
    }

    /**
    * @Route("/partenaire/change_etat/{id}/", name="admin_partenaire_change_etat")
    */
    public function changeEtatPartenaire(Request $request,Partenaires $partenaire)
    {
        if(isset($_POST) && !empty($_POST))
        {
            $repo = $this->getDoctrine()->getRepository(Partenaires::class);
            $partenaire = $repo->find($partenaire->getId());
            if(isset($partenaire) && !empty($partenaire)){
                if(isset($_POST['actif']) && !empty($_POST['actif']))
                    $partenaire->setActif(false);
                else 
                    $partenaire->setActif(true);
            
                $partenaire->setUpdatedAt(new \DateTimeImmutable());
                $em = $this->getDoctrine()->getManager();
                $em->persist($partenaire);
                $em->flush(); 
                $this->addFlash('success', 'L\'état de partenaire a été modifié!');
                return $this->redirectToRoute('admin_partenaires_list');
            }
            else 
            {
                $this->addFlash('error', 'Error de modification de l\'état de partenaire');
                return $this->redirectToRoute('admin_partenaires_list'); 
            }
        }
    }
}
